"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));
var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));
var _fastDeepEqual = _interopRequireDefault(require("fast-deep-equal"));
var _react = require("react");
var _usePrevious = _interopRequireDefault(require("@restart/hooks/usePrevious"));
var _TypeaheadState = require("./TypeaheadState");
var _useValidateProps = _interopRequireDefault(require("./useValidateProps"));
var _utils = require("../utils");
var _constants = require("../constants");
var _excluded = ["onChange"];
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { (0, _defineProperty2["default"])(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
var defaultProps = {
  allowNew: false,
  autoFocus: false,
  caseSensitive: false,
  defaultInputValue: '',
  defaultOpen: false,
  defaultSelected: [],
  filterBy: [],
  highlightOnlyResult: false,
  ignoreDiacritics: true,
  inputProps: {},
  labelKey: _constants.DEFAULT_LABELKEY,
  maxResults: 100,
  minLength: 0,
  multiple: false,
  onBlur: _utils.noop,
  onFocus: _utils.noop,
  onInputChange: _utils.noop,
  onKeyDown: _utils.noop,
  onMenuToggle: _utils.noop,
  onPaginate: _utils.noop,
  paginate: true
};

/**
 * Manually trigger the input's change event.
 * https://stackoverflow.com/questions/23892547/what-is-the-best-way-to-trigger-onchange-event-in-react-js/46012210#46012210
 */
function triggerInputChange(input, value) {
  var inputValue = Object.getOwnPropertyDescriptor(window.HTMLInputElement.prototype, 'value');
  inputValue && inputValue.set && inputValue.set.call(input, value);
  var e = new Event('input', {
    bubbles: true
  });
  input.dispatchEvent(e);
}
function useDidUpdate(props, state, setState) {
  var prevProps = (0, _usePrevious["default"])(props);
  var isInitialRender = (0, _react.useRef)(true);
  (0, _react.useEffect)(function () {
    if (isInitialRender.current) {
      isInitialRender.current = false;
      return;
    }
    (0, _utils.validateSelectedPropChange)(props.selected, prevProps === null || prevProps === void 0 ? void 0 : prevProps.selected);

    // Sync selections in state with those in props.
    if (props.selected && !(0, _fastDeepEqual["default"])(props.selected, state.selected)) {
      setState({
        selected: props.selected
      });
      if (!props.multiple) {
        setState({
          text: props.selected.length ? (0, _utils.getOptionLabel)(props.selected[0], props.labelKey) : ''
        });
      }
    }
  }, [props.labelKey, props.multiple, props.selected, prevProps === null || prevProps === void 0 ? void 0 : prevProps.selected, setState, state.selected]);
}
function useOnMenuToggle(isMenuShown, onMenuToggle) {
  var isInitialRender = (0, _react.useRef)(true);
  (0, _react.useEffect)(function () {
    if (isInitialRender.current) {
      isInitialRender.current = false;
      return;
    }
    onMenuToggle === null || onMenuToggle === void 0 || onMenuToggle(isMenuShown);
  }, [isMenuShown, onMenuToggle]);
}
function useTypeahead(_ref, ref) {
  var onChange = _ref.onChange,
    partialProps = (0, _objectWithoutProperties2["default"])(_ref, _excluded);
  var props = _objectSpread(_objectSpread({}, defaultProps), partialProps);
  var _useTypeaheadState = (0, _TypeaheadState.useTypeaheadState)(props),
    _useTypeaheadState2 = (0, _slicedToArray2["default"])(_useTypeaheadState, 2),
    state = _useTypeaheadState2[0],
    setState = _useTypeaheadState2[1];
  var _useState = (0, _react.useState)(null),
    _useState2 = (0, _slicedToArray2["default"])(_useState, 2),
    inputNode = _useState2[0],
    setInputNode = _useState2[1];
  var mergedPropsAndState = _objectSpread(_objectSpread({}, props), state);
  var filterBy = mergedPropsAndState.filterBy,
    labelKey = mergedPropsAndState.labelKey,
    options = mergedPropsAndState.options,
    paginate = mergedPropsAndState.paginate;
  var isMenuShown = (0, _utils.isShown)(mergedPropsAndState);
  var items = [];
  var hintText = (0, _utils.getHintText)(_objectSpread(_objectSpread({}, mergedPropsAndState), {}, {
    isMenuShown: isMenuShown
  }));
  (0, _useValidateProps["default"])(props);
  useDidUpdate(props, state, setState);
  useOnMenuToggle(isMenuShown, props.onMenuToggle);

  // Imperative methods
  function hideMenu() {
    setState(_TypeaheadState.hideMenu);
  }
  function blur() {
    inputNode === null || inputNode === void 0 || inputNode.blur();
    hideMenu();
  }
  function clear() {
    setState(_TypeaheadState.clearTypeahead);
  }
  var focus = (0, _react.useCallback)(function () {
    inputNode === null || inputNode === void 0 || inputNode.focus();
  }, [inputNode]);
  function getInput() {
    return inputNode;
  }
  function toggleMenu() {
    setState(_TypeaheadState.toggleMenu);
  }
  (0, _react.useImperativeHandle)(ref, function () {
    return {
      blur: blur,
      clear: clear,
      focus: focus,
      getInput: getInput,
      hideMenu: hideMenu,
      toggleMenu: toggleMenu
    };
  });
  (0, _react.useEffect)(function () {
    props.autoFocus && focus();
  }, [props.autoFocus, focus]);
  var results = [];
  if (isMenuShown) {
    var cb = (0, _utils.isFunction)(filterBy) ? filterBy : _utils.defaultFilterBy;
    results = options.filter(function (option) {
      return cb(option, mergedPropsAndState);
    });

    // This must come before results are truncated.
    var shouldPaginate = paginate && results.length > state.shownResults;

    // Truncate results if necessary.
    results = (0, _utils.getTruncatedOptions)(results, state.shownResults);

    // Add the custom option if necessary.
    if ((0, _utils.addCustomOption)(results, mergedPropsAndState)) {
      results.push((0, _defineProperty2["default"])({
        customOption: true
      }, (0, _utils.getStringLabelKey)(labelKey), state.text));
    }

    // Add the pagination item if necessary.
    if (shouldPaginate) {
      results.push((0, _defineProperty2["default"])((0, _defineProperty2["default"])({}, (0, _utils.getStringLabelKey)(labelKey), ''), "paginationOption", true));
    }
  }
  var isOnlyResult = (0, _utils.getIsOnlyResult)(_objectSpread(_objectSpread({}, props), {}, {
    results: results
  }));
  function setItem(item, position) {
    items[position] = item;
  }
  function onActiveIndexChange(index) {
    setState({
      activeIndex: index,
      activeItem: index >= 0 ? items[index] : undefined
    });
  }
  function onBlur(e) {
    setState(_objectSpread(_objectSpread({}, (0, _TypeaheadState.hideMenu)(state, props)), {}, {
      isFocused: false
    }), function () {
      return props.onBlur(e);
    });
  }
  function onSelect(newSelected) {
    onChange && onChange(newSelected);
  }
  function onClear() {
    inputNode && triggerInputChange(inputNode, '');
    setState(_TypeaheadState.clearTypeahead, function () {
      // Change handler is automatically triggered for single selections but
      // not multi-selections.
      if (props.multiple) {
        onSelect([]);
      }
    });
  }
  function onClick(e) {
    var _props$inputProps;
    var handleClick = (_props$inputProps = props.inputProps) === null || _props$inputProps === void 0 ? void 0 : _props$inputProps.onClick;
    setState(_TypeaheadState.clickOrFocusInput, function () {
      return handleClick && handleClick(e);
    });
  }
  function onFocus(e) {
    setState(_TypeaheadState.clickOrFocusInput, function () {
      return props.onFocus(e);
    });
  }
  function onInitialItemChange(initialItem) {
    // Don't update the initial item if it hasn't changed.
    if (!(0, _fastDeepEqual["default"])(initialItem, state.initialItem)) {
      setState({
        initialItem: initialItem
      });
    }
  }
  function onInputChange(e) {
    var value = e.currentTarget.value;

    // Clear selections when the input value changes in single-select mode.
    var shouldClearSelections = state.selected.length && !props.multiple;
    var _getInitialState = (0, _TypeaheadState.getInitialState)(props),
      activeIndex = _getInitialState.activeIndex,
      activeItem = _getInitialState.activeItem,
      shownResults = _getInitialState.shownResults;
    setState({
      activeIndex: activeIndex,
      activeItem: activeItem,
      selected: shouldClearSelections ? [] : state.selected,
      showMenu: true,
      shownResults: shownResults,
      text: value
    });
    props.onInputChange(value, e);
    shouldClearSelections && onSelect([]);
  }
  function onAdd(option) {
    var selected;
    var selection = option;
    var text = '';

    // Add a unique id to the custom selection. Avoid doing this in `render` so
    // the id doesn't increment every time.
    if (!(0, _utils.isString)(selection) && selection.customOption) {
      selection = _objectSpread(_objectSpread({}, selection), {}, {
        id: (0, _utils.uniqueId)('new-id-')
      });
    }
    if (props.multiple) {
      // If multiple selections are allowed, add the new selection to the
      // existing selections.
      selected = [].concat((0, _toConsumableArray2["default"])(state.selected), [selection]);
    } else {
      // If only a single selection is allowed, replace the existing selection
      // with the new one.
      selected = [selection];
      text = (0, _utils.getOptionLabel)(selection, props.labelKey);
    }
    setState(_objectSpread(_objectSpread({}, (0, _TypeaheadState.hideMenu)(state, props)), {}, {
      initialItem: selection,
      selected: selected,
      text: text
    }), function (newState) {
      return onSelect(newState.selected);
    });
  }
  function onPaginate(e) {
    setState(function (currentState) {
      return {
        shownResults: currentState.shownResults + props.maxResults
      };
    }, function (newState) {
      return props.onPaginate(e, newState.shownResults);
    });
  }
  function onMenuItemSelect(option, e) {
    if ((0, _utils.getOptionProperty)(option, 'paginationOption')) {
      onPaginate(e);
    } else {
      onAdd(option);
    }
  }
  function onKeyDown(e) {
    props.onKeyDown(e);

    // Skip most actions when the menu is hidden.
    if (!isMenuShown) {
      if (e.key === 'ArrowUp' || e.key === 'ArrowDown') {
        setState({
          showMenu: true
        });
      }
      return;
    }
    switch (e.key) {
      case 'ArrowUp':
      case 'ArrowDown':
        // Prevent input cursor from going to the beginning when pressing up.
        e.preventDefault();
        onActiveIndexChange((0, _utils.getUpdatedActiveIndex)(state.activeIndex, e.key, items));
        break;
      case 'Enter':
        // Prevent form submission while menu is open.
        e.preventDefault();
        state.activeItem && onMenuItemSelect(state.activeItem, e);
        break;
      case 'Escape':
      case 'Tab':
        // ESC simply hides the menu. TAB will blur the input and move focus to
        // the next item; hide the menu so it doesn't gain focus.
        hideMenu();
        break;
      default:
        break;
    }
    if (!state.initialItem) {
      return;
    }
    var addOnlyResult = e.key === 'Enter' && isOnlyResult;
    var shouldSelectHint = hintText && (0, _utils.defaultSelectHint)(e, props.selectHint);
    if (addOnlyResult || shouldSelectHint) {
      onAdd(state.initialItem);
    }
  }
  function onRemove(selection) {
    var selected = state.selected.filter(function (option) {
      return !(0, _fastDeepEqual["default"])(option, selection);
    });

    // Make sure the input stays focused after the item is removed.
    focus();
    setState(_objectSpread(_objectSpread({}, (0, _TypeaheadState.hideMenu)(state, props)), {}, {
      selected: selected
    }), function () {
      return onSelect(selected);
    });
  }
  (0, _react.useEffect)(function () {
    // Clear the initial item when there are no results.
    if (!(props.allowNew || results.length)) {
      onInitialItemChange();
    }
  });
  var context = {
    activeIndex: state.activeIndex,
    hintText: hintText,
    id: props.id,
    initialItem: state.initialItem,
    inputNode: inputNode,
    isOnlyResult: isOnlyResult,
    onAdd: onAdd,
    onInitialItemChange: onInitialItemChange,
    onMenuItemClick: onMenuItemSelect,
    setItem: setItem
  };
  return _objectSpread(_objectSpread({}, mergedPropsAndState), {}, {
    context: context,
    getInputProps: (0, _utils.getInputProps)({
      activeIndex: state.activeIndex,
      id: props.id,
      inputRef: setInputNode,
      isFocused: state.isFocused,
      isMenuShown: isMenuShown,
      multiple: props.multiple,
      onBlur: onBlur,
      onChange: onInputChange,
      onClick: onClick,
      onFocus: onFocus,
      onKeyDown: onKeyDown,
      value: (0, _utils.getInputText)(mergedPropsAndState)
    }),
    getMenuProps: (0, _utils.getMenuProps)({
      id: props.id
    }),
    hideMenu: hideMenu,
    inputNode: inputNode,
    isMenuShown: isMenuShown,
    onClear: onClear,
    onHide: hideMenu,
    onRemove: onRemove,
    results: results,
    toggleMenu: toggleMenu
  });
}
var _default = exports["default"] = useTypeahead;