"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = void 0;
var _react = require("react");
var _utils = require("../utils");
var INPUT_PROPS_BLACKLIST = [{
  alt: 'onBlur',
  prop: 'onBlur'
}, {
  alt: 'onInputChange',
  prop: 'onChange'
}, {
  alt: 'onFocus',
  prop: 'onFocus'
}, {
  alt: 'onKeyDown',
  prop: 'onKeyDown'
}];
function useValidateProps(_ref) {
  var allowNew = _ref.allowNew,
    caseSensitive = _ref.caseSensitive,
    defaultInputValue = _ref.defaultInputValue,
    _ref$defaultSelected = _ref.defaultSelected,
    defaultSelected = _ref$defaultSelected === void 0 ? [] : _ref$defaultSelected,
    filterBy = _ref.filterBy,
    highlightOnlyResult = _ref.highlightOnlyResult,
    id = _ref.id,
    ignoreDiacritics = _ref.ignoreDiacritics,
    inputProps = _ref.inputProps,
    labelKey = _ref.labelKey,
    multiple = _ref.multiple,
    onChange = _ref.onChange,
    selected = _ref.selected;
  (0, _react.useEffect)(function () {
    var name = defaultSelected.length ? 'defaultSelected' : 'selected';
    (0, _utils.warn)(id != null, 'The `id` prop is required to make `Menu` accessible for users of ' + 'assistive technologies such as screen readers.');
    (0, _utils.warn)(!(!multiple && defaultInputValue && (defaultSelected.length || selected && selected.length)), "`defaultInputValue` will be overridden by the value from `".concat(name, "`."));
    (0, _utils.warn)(multiple || defaultSelected.length <= 1, 'You are passing multiple options to the `defaultSelected` prop of a ' + 'Typeahead in single-select mode. The selections will be truncated to a ' + 'single selection.');
    (0, _utils.warn)(!(highlightOnlyResult && allowNew), '`highlightOnlyResult` will not work with `allowNew`.');
    (0, _utils.warn)(!caseSensitive || typeof filterBy !== 'function', 'Your `filterBy` function will override the `caseSensitive` prop.');
    (0, _utils.warn)(ignoreDiacritics || typeof filterBy !== 'function', 'Your `filterBy` function will override the `ignoreDiacritics` prop.');
    if (!(inputProps && Object.prototype.toString.call(inputProps) === '[object Object]')) {
      return;
    }

    // Blacklisted properties.
    INPUT_PROPS_BLACKLIST.forEach(function (_ref2) {
      var alt = _ref2.alt,
        prop = _ref2.prop;
      var msg = alt ? " Use the top-level `".concat(alt, "` prop instead.") : null;
      (0, _utils.warn)(!inputProps[prop], "The `".concat(prop, "` property of `inputProps` will be ignored.").concat(msg));
    });
    (0, _utils.warn)(!((0, _utils.isFunction)(labelKey) && allowNew), '`labelKey` must be a string when using `allowNew`.');
    (0, _utils.warn)(multiple || !selected || selected.length <= 1, 'You are passing multiple options to the `selected` prop of a Typeahead ' + 'in single-select mode. This may lead to unexpected behaviors or errors.');
    (0, _utils.warn)(!selected || selected && (0, _utils.isFunction)(onChange), 'You provided a `selected` prop without an `onChange` handler. If you ' + 'want the typeahead to be uncontrolled, use `defaultSelected`. ' + 'Otherwise, set `onChange`.');
  }, [allowNew, caseSensitive, defaultInputValue, defaultSelected, filterBy, highlightOnlyResult, id, ignoreDiacritics, inputProps, labelKey, multiple, onChange, selected]);
}
var _default = exports["default"] = useValidateProps;