import cx from 'classnames';
import React, { forwardRef, useState } from 'react';
import { TypeaheadContext, useTypeahead } from '../../core';
import { useOverlay } from '../../hooks';
import ClearButton from '../ClearButton';
import Loader from '../Loader';
import Token from '../Token';
import TypeaheadInputMulti from '../TypeaheadInputMulti';
import TypeaheadInputSingle from '../TypeaheadInputSingle';
import TypeaheadMenu from '../TypeaheadMenu';
import { getOptionLabel, isFunction, isSizeLarge, preventInputBlur, } from '../../utils';
const defaultRenderMenu = (results, menuProps, props) => (React.createElement(TypeaheadMenu, { ...menuProps, labelKey: props.labelKey, options: results, text: props.text }));
const defaultRenderToken = (option, props, idx) => (React.createElement(Token, { disabled: props.disabled, key: idx, onRemove: props.onRemove, option: option, tabIndex: props.tabIndex }, getOptionLabel(option, props.labelKey)));
const Typeahead = forwardRef((props, ref) => {
    const { context, ...rest } = useTypeahead(props, ref);
    const { children, clearButton, disabled, emptyLabel, isLoading, isInvalid, isValid, maxHeight, multiple, newSelectionPrefix, paginationText, placeholder, renderMenuItemChildren, size, } = props;
    const { getInputProps, getMenuProps, isMenuShown, labelKey, onClear, onRemove, results, selected, } = rest;
    const [referenceElement, setReferenceElement] = useState(null);
    const overlayProps = useOverlay(referenceElement, props);
    const renderMenu = props.renderMenu || defaultRenderMenu;
    const menuProps = {
        emptyLabel,
        maxHeight,
        newSelectionPrefix,
        paginationText,
        renderMenuItemChildren,
        ...overlayProps,
        ...getMenuProps(),
    };
    function renderInput() {
        const inputProps = {
            ...getInputProps({
                ...props.inputProps,
                disabled,
                placeholder,
            }),
            referenceElementRef: setReferenceElement,
        };
        if (props.renderInput) {
            return props.renderInput(inputProps, rest);
        }
        const commonProps = {
            ...inputProps,
            isInvalid,
            isValid,
            size,
        };
        if (!multiple) {
            return React.createElement(TypeaheadInputSingle, { ...commonProps });
        }
        const renderToken = props.renderToken || defaultRenderToken;
        const tokenProps = {
            ...commonProps,
            labelKey,
            onRemove,
        };
        return (React.createElement(TypeaheadInputMulti, { ...commonProps, placeholder: selected.length ? '' : inputProps.placeholder, selected: selected }, selected.map((option, idx) => renderToken(option, tokenProps, idx))));
    }
    let auxContent;
    if (isLoading) {
        auxContent = React.createElement(Loader, null);
    }
    else if (clearButton && !disabled && selected?.length) {
        auxContent = (React.createElement(ClearButton, { onClick: onClear, onMouseDown: preventInputBlur, size: size }));
    }
    return (React.createElement(TypeaheadContext.Provider, { value: context },
        React.createElement("div", { className: cx('rbt', {
                'has-aux': !!auxContent,
                'is-invalid': isInvalid,
                'is-valid': isValid,
            }, props.className), style: {
                ...props.style,
                outline: 'none',
                position: 'relative',
            }, tabIndex: -1 },
            renderInput(),
            isMenuShown && renderMenu(results, menuProps, rest),
            auxContent && (React.createElement("div", { className: cx('rbt-aux', { 'rbt-aux-lg': isSizeLarge(size) }) }, auxContent)),
            isFunction(children) ? children(rest) : children)));
});
export default Typeahead;
