import { useEffect, useReducer, useRef } from 'react';
import { getOptionLabel, isFunction } from '../utils';
export function getInitialState({ defaultInputValue, defaultOpen, defaultSelected, labelKey, maxResults, multiple, ...props }) {
    let selected = props.selected
        ? props.selected.slice()
        : defaultSelected.slice();
    let text = defaultInputValue;
    if (!multiple && selected.length) {
        text = getOptionLabel(selected[0], labelKey);
        if (selected.length > 1) {
            selected = selected.slice(0, 1);
        }
    }
    return {
        activeIndex: -1,
        activeItem: undefined,
        initialItem: undefined,
        isFocused: false,
        selected,
        showMenu: defaultOpen,
        shownResults: maxResults,
        text,
    };
}
export function clearTypeahead(state, props) {
    return {
        ...getInitialState(props),
        isFocused: state.isFocused,
        selected: [],
        text: '',
    };
}
export function clickOrFocusInput(state) {
    return {
        ...state,
        isFocused: true,
        showMenu: true,
    };
}
export function hideMenu(state, props) {
    const { activeIndex, activeItem, initialItem, shownResults } = getInitialState(props);
    return {
        ...state,
        activeIndex,
        activeItem,
        initialItem,
        showMenu: false,
        shownResults,
    };
}
export function toggleMenu(state, props) {
    return state.showMenu ? hideMenu(state, props) : { ...state, showMenu: true };
}
function reducer(state, newState) {
    return {
        ...state,
        ...newState,
    };
}
export function useTypeaheadState(props) {
    const initialState = getInitialState(props);
    const [state, dispatch] = useReducer(reducer, initialState);
    const callbackQueue = useRef([]);
    useEffect(() => {
        if (callbackQueue.current.length) {
            callbackQueue.current.forEach((callback) => {
                callback(state);
            });
        }
        callbackQueue.current = [];
    }, [state]);
    function setState(stateObjOrFn, cb) {
        const newState = isFunction(stateObjOrFn)
            ? stateObjOrFn(state, props)
            : stateObjOrFn;
        cb && callbackQueue.current.push(cb);
        dispatch(newState);
    }
    return [state, setState];
}
