import debounce from 'lodash.debounce';
import { useCallback, useEffect, useRef } from 'react';
import useForceUpdate from '@restart/hooks/useForceUpdate';
import usePrevious from '@restart/hooks/usePrevious';
import { isFunction } from '../utils';
function useAsync(props) {
    const { allowNew, delay = 200, emptyLabel, isLoading, minLength = 2, onInputChange, onSearch, options = [], promptText = 'Type to search...', searchText = 'Searching...', useCache = true, ...otherProps } = props;
    const cacheRef = useRef({});
    const handleSearchDebouncedRef = useRef(null);
    const queryRef = useRef(props.defaultInputValue || '');
    const forceUpdate = useForceUpdate();
    const prevProps = usePrevious(props);
    const handleSearch = useCallback((query) => {
        queryRef.current = query;
        if (!query || (minLength && query.length < minLength)) {
            return;
        }
        if (useCache && cacheRef.current[query]) {
            forceUpdate();
            return;
        }
        onSearch(query);
    }, [forceUpdate, minLength, onSearch, useCache]);
    useEffect(() => {
        handleSearchDebouncedRef.current = debounce(handleSearch, delay);
        return () => {
            handleSearchDebouncedRef.current &&
                handleSearchDebouncedRef.current.cancel();
        };
    }, [delay, handleSearch]);
    useEffect(() => {
        if (!isLoading && prevProps && prevProps.isLoading && useCache) {
            cacheRef.current[queryRef.current] = options;
        }
    });
    const getEmptyLabel = () => {
        if (!queryRef.current.length) {
            return promptText;
        }
        if (isLoading) {
            return searchText;
        }
        return emptyLabel;
    };
    const handleInputChange = useCallback((query, e) => {
        onInputChange && onInputChange(query, e);
        handleSearchDebouncedRef.current &&
            handleSearchDebouncedRef.current(query);
    }, [onInputChange]);
    const cachedQuery = cacheRef.current[queryRef.current];
    return {
        ...otherProps,
        allowNew: isFunction(allowNew) ? allowNew : allowNew && !isLoading,
        emptyLabel: getEmptyLabel(),
        isLoading,
        minLength,
        onInputChange: handleInputChange,
        options: useCache && cachedQuery ? cachedQuery : options,
    };
}
export default useAsync;
