import { HTMLProps, MouseEvent, MouseEventHandler } from 'react';
import { preventInputBlur } from '../utils';
import { Option } from '../types';
export interface UseItemProps<T> extends HTMLProps<T> {
    onClick?: MouseEventHandler<T>;
    option: Option;
    position: number;
}
declare function useItem<T extends HTMLElement>({ label, onClick, option, position, ...props }: UseItemProps<T>): {
    active: boolean;
    'aria-label': string | undefined;
    'aria-selected': boolean;
    id: string;
    onClick: (e: MouseEvent<T>) => void;
    onMouseDown: typeof preventInputBlur;
    ref: import("react").RefObject<T>;
    role: string;
    accept?: string | undefined;
    acceptCharset?: string | undefined;
    action?: string | undefined;
    allowFullScreen?: boolean | undefined;
    allowTransparency?: boolean | undefined;
    alt?: string | undefined;
    as?: string | undefined;
    async?: boolean | undefined;
    autoComplete?: string | undefined;
    autoPlay?: boolean | undefined;
    capture?: boolean | "user" | "environment" | undefined;
    cellPadding?: string | number | undefined;
    cellSpacing?: string | number | undefined;
    charSet?: string | undefined;
    challenge?: string | undefined;
    checked?: boolean | undefined;
    cite?: string | undefined;
    classID?: string | undefined;
    cols?: number | undefined;
    colSpan?: number | undefined;
    controls?: boolean | undefined;
    coords?: string | undefined;
    crossOrigin?: "" | "anonymous" | "use-credentials" | undefined;
    data?: string | undefined;
    dateTime?: string | undefined;
    default?: boolean | undefined;
    defer?: boolean | undefined;
    disabled?: boolean | undefined;
    download?: any;
    encType?: string | undefined;
    form?: string | undefined;
    formAction?: string | undefined;
    formEncType?: string | undefined;
    formMethod?: string | undefined;
    formNoValidate?: boolean | undefined;
    formTarget?: string | undefined;
    frameBorder?: string | number | undefined;
    headers?: string | undefined;
    height?: string | number | undefined;
    high?: number | undefined;
    href?: string | undefined;
    hrefLang?: string | undefined;
    htmlFor?: string | undefined;
    httpEquiv?: string | undefined;
    integrity?: string | undefined;
    keyParams?: string | undefined;
    keyType?: string | undefined;
    kind?: string | undefined;
    list?: string | undefined;
    loop?: boolean | undefined;
    low?: number | undefined;
    manifest?: string | undefined;
    marginHeight?: number | undefined;
    marginWidth?: number | undefined;
    max?: string | number | undefined;
    maxLength?: number | undefined;
    media?: string | undefined;
    mediaGroup?: string | undefined;
    method?: string | undefined;
    min?: string | number | undefined;
    minLength?: number | undefined;
    multiple?: boolean | undefined;
    muted?: boolean | undefined;
    name?: string | undefined;
    noValidate?: boolean | undefined;
    open?: boolean | undefined;
    optimum?: number | undefined;
    pattern?: string | undefined;
    placeholder?: string | undefined;
    playsInline?: boolean | undefined;
    poster?: string | undefined;
    preload?: string | undefined;
    readOnly?: boolean | undefined;
    required?: boolean | undefined;
    reversed?: boolean | undefined;
    rows?: number | undefined;
    rowSpan?: number | undefined;
    sandbox?: string | undefined;
    scope?: string | undefined;
    scoped?: boolean | undefined;
    scrolling?: string | undefined;
    seamless?: boolean | undefined;
    selected?: boolean | undefined;
    shape?: string | undefined;
    size?: number | undefined;
    sizes?: string | undefined;
    span?: number | undefined;
    src?: string | undefined;
    srcDoc?: string | undefined;
    srcLang?: string | undefined;
    srcSet?: string | undefined;
    start?: number | undefined;
    step?: string | number | undefined;
    summary?: string | undefined;
    target?: string | undefined;
    type?: string | undefined;
    useMap?: string | undefined;
    value?: string | number | readonly string[] | undefined;
    width?: string | number | undefined;
    wmode?: string | undefined;
    wrap?: string | undefined;
    defaultChecked?: boolean | undefined;
    defaultValue?: string | number | readonly string[] | undefined;
    suppressContentEditableWarning?: boolean | undefined;
    suppressHydrationWarning?: boolean | undefined;
    accessKey?: string | undefined;
    autoCapitalize?: "none" | "off" | "on" | (string & {}) | "sentences" | "words" | "characters" | undefined;
    autoFocus?: boolean | undefined;
    className?: string | undefined;
    contentEditable?: (boolean | "true" | "false") | "inherit" | "plaintext-only" | undefined;
    contextMenu?: string | undefined;
    dir?: string | undefined;
    draggable?: (boolean | "true" | "false") | undefined;
    enterKeyHint?: "search" | "enter" | "done" | "go" | "next" | "previous" | "send" | undefined;
    hidden?: boolean | undefined;
    lang?: string | undefined;
    nonce?: string | undefined;
    slot?: string | undefined;
    spellCheck?: (boolean | "true" | "false") | undefined;
    style?: import("react").CSSProperties | undefined;
    tabIndex?: number | undefined;
    title?: string | undefined;
    translate?: "yes" | "no" | undefined;
    radioGroup?: string | undefined;
    about?: string | undefined;
    content?: string | undefined;
    datatype?: string | undefined;
    inlist?: any;
    prefix?: string | undefined;
    property?: string | undefined;
    rel?: string | undefined;
    resource?: string | undefined;
    rev?: string | undefined;
    typeof?: string | undefined;
    vocab?: string | undefined;
    autoCorrect?: string | undefined;
    autoSave?: string | undefined;
    color?: string | undefined;
    itemProp?: string | undefined;
    itemScope?: boolean | undefined;
    itemType?: string | undefined;
    itemID?: string | undefined;
    itemRef?: string | undefined;
    results?: number | undefined;
    security?: string | undefined;
    unselectable?: "off" | "on" | undefined;
    inputMode?: "text" | "none" | "email" | "tel" | "search" | "url" | "numeric" | "decimal" | undefined;
    is?: string | undefined;
    "aria-activedescendant"?: string | undefined;
    "aria-atomic"?: (boolean | "true" | "false") | undefined;
    "aria-autocomplete"?: "list" | "none" | "both" | "inline" | undefined;
    "aria-braillelabel"?: string | undefined;
    "aria-brailleroledescription"?: string | undefined;
    "aria-busy"?: (boolean | "true" | "false") | undefined;
    "aria-checked"?: boolean | "true" | "false" | "mixed" | undefined;
    "aria-colcount"?: number | undefined;
    "aria-colindex"?: number | undefined;
    "aria-colindextext"?: string | undefined;
    "aria-colspan"?: number | undefined;
    "aria-controls"?: string | undefined;
    "aria-current"?: boolean | "step" | "date" | "time" | "true" | "false" | "page" | "location" | undefined;
    "aria-describedby"?: string | undefined;
    "aria-description"?: string | undefined;
    "aria-details"?: string | undefined;
    "aria-disabled"?: (boolean | "true" | "false") | undefined;
    "aria-dropeffect"?: "none" | "copy" | "execute" | "link" | "move" | "popup" | undefined;
    "aria-errormessage"?: string | undefined;
    "aria-expanded"?: (boolean | "true" | "false") | undefined;
    "aria-flowto"?: string | undefined;
    "aria-grabbed"?: (boolean | "true" | "false") | undefined;
    "aria-haspopup"?: boolean | "listbox" | "true" | "false" | "menu" | "tree" | "grid" | "dialog" | undefined;
    "aria-hidden"?: (boolean | "true" | "false") | undefined;
    "aria-invalid"?: boolean | "true" | "false" | "grammar" | "spelling" | undefined;
    "aria-keyshortcuts"?: string | undefined;
    "aria-labelledby"?: string | undefined;
    "aria-level"?: number | undefined;
    "aria-live"?: "off" | "assertive" | "polite" | undefined;
    "aria-modal"?: (boolean | "true" | "false") | undefined;
    "aria-multiline"?: (boolean | "true" | "false") | undefined;
    "aria-multiselectable"?: (boolean | "true" | "false") | undefined;
    "aria-orientation"?: "horizontal" | "vertical" | undefined;
    "aria-owns"?: string | undefined;
    "aria-placeholder"?: string | undefined;
    "aria-posinset"?: number | undefined;
    "aria-pressed"?: boolean | "true" | "false" | "mixed" | undefined;
    "aria-readonly"?: (boolean | "true" | "false") | undefined;
    "aria-relevant"?: "text" | "additions" | "additions removals" | "additions text" | "all" | "removals" | "removals additions" | "removals text" | "text additions" | "text removals" | undefined;
    "aria-required"?: (boolean | "true" | "false") | undefined;
    "aria-roledescription"?: string | undefined;
    "aria-rowcount"?: number | undefined;
    "aria-rowindex"?: number | undefined;
    "aria-rowindextext"?: string | undefined;
    "aria-rowspan"?: number | undefined;
    "aria-setsize"?: number | undefined;
    "aria-sort"?: "none" | "ascending" | "descending" | "other" | undefined;
    "aria-valuemax"?: number | undefined;
    "aria-valuemin"?: number | undefined;
    "aria-valuenow"?: number | undefined;
    "aria-valuetext"?: string | undefined;
    children?: import("react").ReactNode;
    dangerouslySetInnerHTML?: {
        __html: string | TrustedHTML;
    } | undefined;
    onCopy?: import("react").ClipboardEventHandler<T> | undefined;
    onCopyCapture?: import("react").ClipboardEventHandler<T> | undefined;
    onCut?: import("react").ClipboardEventHandler<T> | undefined;
    onCutCapture?: import("react").ClipboardEventHandler<T> | undefined;
    onPaste?: import("react").ClipboardEventHandler<T> | undefined;
    onPasteCapture?: import("react").ClipboardEventHandler<T> | undefined;
    onCompositionEnd?: import("react").CompositionEventHandler<T> | undefined;
    onCompositionEndCapture?: import("react").CompositionEventHandler<T> | undefined;
    onCompositionStart?: import("react").CompositionEventHandler<T> | undefined;
    onCompositionStartCapture?: import("react").CompositionEventHandler<T> | undefined;
    onCompositionUpdate?: import("react").CompositionEventHandler<T> | undefined;
    onCompositionUpdateCapture?: import("react").CompositionEventHandler<T> | undefined;
    onFocus?: import("react").FocusEventHandler<T> | undefined;
    onFocusCapture?: import("react").FocusEventHandler<T> | undefined;
    onBlur?: import("react").FocusEventHandler<T> | undefined;
    onBlurCapture?: import("react").FocusEventHandler<T> | undefined;
    onChange?: import("react").FormEventHandler<T> | undefined;
    onChangeCapture?: import("react").FormEventHandler<T> | undefined;
    onBeforeInput?: import("react").FormEventHandler<T> | undefined;
    onBeforeInputCapture?: import("react").FormEventHandler<T> | undefined;
    onInput?: import("react").FormEventHandler<T> | undefined;
    onInputCapture?: import("react").FormEventHandler<T> | undefined;
    onReset?: import("react").FormEventHandler<T> | undefined;
    onResetCapture?: import("react").FormEventHandler<T> | undefined;
    onSubmit?: import("react").FormEventHandler<T> | undefined;
    onSubmitCapture?: import("react").FormEventHandler<T> | undefined;
    onInvalid?: import("react").FormEventHandler<T> | undefined;
    onInvalidCapture?: import("react").FormEventHandler<T> | undefined;
    onLoad?: import("react").ReactEventHandler<T> | undefined;
    onLoadCapture?: import("react").ReactEventHandler<T> | undefined;
    onError?: import("react").ReactEventHandler<T> | undefined;
    onErrorCapture?: import("react").ReactEventHandler<T> | undefined;
    onKeyDown?: import("react").KeyboardEventHandler<T> | undefined;
    onKeyDownCapture?: import("react").KeyboardEventHandler<T> | undefined;
    onKeyPress?: import("react").KeyboardEventHandler<T> | undefined;
    onKeyPressCapture?: import("react").KeyboardEventHandler<T> | undefined;
    onKeyUp?: import("react").KeyboardEventHandler<T> | undefined;
    onKeyUpCapture?: import("react").KeyboardEventHandler<T> | undefined;
    onAbort?: import("react").ReactEventHandler<T> | undefined;
    onAbortCapture?: import("react").ReactEventHandler<T> | undefined;
    onCanPlay?: import("react").ReactEventHandler<T> | undefined;
    onCanPlayCapture?: import("react").ReactEventHandler<T> | undefined;
    onCanPlayThrough?: import("react").ReactEventHandler<T> | undefined;
    onCanPlayThroughCapture?: import("react").ReactEventHandler<T> | undefined;
    onDurationChange?: import("react").ReactEventHandler<T> | undefined;
    onDurationChangeCapture?: import("react").ReactEventHandler<T> | undefined;
    onEmptied?: import("react").ReactEventHandler<T> | undefined;
    onEmptiedCapture?: import("react").ReactEventHandler<T> | undefined;
    onEncrypted?: import("react").ReactEventHandler<T> | undefined;
    onEncryptedCapture?: import("react").ReactEventHandler<T> | undefined;
    onEnded?: import("react").ReactEventHandler<T> | undefined;
    onEndedCapture?: import("react").ReactEventHandler<T> | undefined;
    onLoadedData?: import("react").ReactEventHandler<T> | undefined;
    onLoadedDataCapture?: import("react").ReactEventHandler<T> | undefined;
    onLoadedMetadata?: import("react").ReactEventHandler<T> | undefined;
    onLoadedMetadataCapture?: import("react").ReactEventHandler<T> | undefined;
    onLoadStart?: import("react").ReactEventHandler<T> | undefined;
    onLoadStartCapture?: import("react").ReactEventHandler<T> | undefined;
    onPause?: import("react").ReactEventHandler<T> | undefined;
    onPauseCapture?: import("react").ReactEventHandler<T> | undefined;
    onPlay?: import("react").ReactEventHandler<T> | undefined;
    onPlayCapture?: import("react").ReactEventHandler<T> | undefined;
    onPlaying?: import("react").ReactEventHandler<T> | undefined;
    onPlayingCapture?: import("react").ReactEventHandler<T> | undefined;
    onProgress?: import("react").ReactEventHandler<T> | undefined;
    onProgressCapture?: import("react").ReactEventHandler<T> | undefined;
    onRateChange?: import("react").ReactEventHandler<T> | undefined;
    onRateChangeCapture?: import("react").ReactEventHandler<T> | undefined;
    onResize?: import("react").ReactEventHandler<T> | undefined;
    onResizeCapture?: import("react").ReactEventHandler<T> | undefined;
    onSeeked?: import("react").ReactEventHandler<T> | undefined;
    onSeekedCapture?: import("react").ReactEventHandler<T> | undefined;
    onSeeking?: import("react").ReactEventHandler<T> | undefined;
    onSeekingCapture?: import("react").ReactEventHandler<T> | undefined;
    onStalled?: import("react").ReactEventHandler<T> | undefined;
    onStalledCapture?: import("react").ReactEventHandler<T> | undefined;
    onSuspend?: import("react").ReactEventHandler<T> | undefined;
    onSuspendCapture?: import("react").ReactEventHandler<T> | undefined;
    onTimeUpdate?: import("react").ReactEventHandler<T> | undefined;
    onTimeUpdateCapture?: import("react").ReactEventHandler<T> | undefined;
    onVolumeChange?: import("react").ReactEventHandler<T> | undefined;
    onVolumeChangeCapture?: import("react").ReactEventHandler<T> | undefined;
    onWaiting?: import("react").ReactEventHandler<T> | undefined;
    onWaitingCapture?: import("react").ReactEventHandler<T> | undefined;
    onAuxClick?: MouseEventHandler<T> | undefined;
    onAuxClickCapture?: MouseEventHandler<T> | undefined;
    onClickCapture?: MouseEventHandler<T> | undefined;
    onContextMenu?: MouseEventHandler<T> | undefined;
    onContextMenuCapture?: MouseEventHandler<T> | undefined;
    onDoubleClick?: MouseEventHandler<T> | undefined;
    onDoubleClickCapture?: MouseEventHandler<T> | undefined;
    onDrag?: import("react").DragEventHandler<T> | undefined;
    onDragCapture?: import("react").DragEventHandler<T> | undefined;
    onDragEnd?: import("react").DragEventHandler<T> | undefined;
    onDragEndCapture?: import("react").DragEventHandler<T> | undefined;
    onDragEnter?: import("react").DragEventHandler<T> | undefined;
    onDragEnterCapture?: import("react").DragEventHandler<T> | undefined;
    onDragExit?: import("react").DragEventHandler<T> | undefined;
    onDragExitCapture?: import("react").DragEventHandler<T> | undefined;
    onDragLeave?: import("react").DragEventHandler<T> | undefined;
    onDragLeaveCapture?: import("react").DragEventHandler<T> | undefined;
    onDragOver?: import("react").DragEventHandler<T> | undefined;
    onDragOverCapture?: import("react").DragEventHandler<T> | undefined;
    onDragStart?: import("react").DragEventHandler<T> | undefined;
    onDragStartCapture?: import("react").DragEventHandler<T> | undefined;
    onDrop?: import("react").DragEventHandler<T> | undefined;
    onDropCapture?: import("react").DragEventHandler<T> | undefined;
    onMouseDownCapture?: MouseEventHandler<T> | undefined;
    onMouseEnter?: MouseEventHandler<T> | undefined;
    onMouseLeave?: MouseEventHandler<T> | undefined;
    onMouseMove?: MouseEventHandler<T> | undefined;
    onMouseMoveCapture?: MouseEventHandler<T> | undefined;
    onMouseOut?: MouseEventHandler<T> | undefined;
    onMouseOutCapture?: MouseEventHandler<T> | undefined;
    onMouseOver?: MouseEventHandler<T> | undefined;
    onMouseOverCapture?: MouseEventHandler<T> | undefined;
    onMouseUp?: MouseEventHandler<T> | undefined;
    onMouseUpCapture?: MouseEventHandler<T> | undefined;
    onSelect?: import("react").ReactEventHandler<T> | undefined;
    onSelectCapture?: import("react").ReactEventHandler<T> | undefined;
    onTouchCancel?: import("react").TouchEventHandler<T> | undefined;
    onTouchCancelCapture?: import("react").TouchEventHandler<T> | undefined;
    onTouchEnd?: import("react").TouchEventHandler<T> | undefined;
    onTouchEndCapture?: import("react").TouchEventHandler<T> | undefined;
    onTouchMove?: import("react").TouchEventHandler<T> | undefined;
    onTouchMoveCapture?: import("react").TouchEventHandler<T> | undefined;
    onTouchStart?: import("react").TouchEventHandler<T> | undefined;
    onTouchStartCapture?: import("react").TouchEventHandler<T> | undefined;
    onPointerDown?: import("react").PointerEventHandler<T> | undefined;
    onPointerDownCapture?: import("react").PointerEventHandler<T> | undefined;
    onPointerMove?: import("react").PointerEventHandler<T> | undefined;
    onPointerMoveCapture?: import("react").PointerEventHandler<T> | undefined;
    onPointerUp?: import("react").PointerEventHandler<T> | undefined;
    onPointerUpCapture?: import("react").PointerEventHandler<T> | undefined;
    onPointerCancel?: import("react").PointerEventHandler<T> | undefined;
    onPointerCancelCapture?: import("react").PointerEventHandler<T> | undefined;
    onPointerEnter?: import("react").PointerEventHandler<T> | undefined;
    onPointerLeave?: import("react").PointerEventHandler<T> | undefined;
    onPointerOver?: import("react").PointerEventHandler<T> | undefined;
    onPointerOverCapture?: import("react").PointerEventHandler<T> | undefined;
    onPointerOut?: import("react").PointerEventHandler<T> | undefined;
    onPointerOutCapture?: import("react").PointerEventHandler<T> | undefined;
    onGotPointerCapture?: import("react").PointerEventHandler<T> | undefined;
    onGotPointerCaptureCapture?: import("react").PointerEventHandler<T> | undefined;
    onLostPointerCapture?: import("react").PointerEventHandler<T> | undefined;
    onLostPointerCaptureCapture?: import("react").PointerEventHandler<T> | undefined;
    onScroll?: import("react").UIEventHandler<T> | undefined;
    onScrollCapture?: import("react").UIEventHandler<T> | undefined;
    onWheel?: import("react").WheelEventHandler<T> | undefined;
    onWheelCapture?: import("react").WheelEventHandler<T> | undefined;
    onAnimationStart?: import("react").AnimationEventHandler<T> | undefined;
    onAnimationStartCapture?: import("react").AnimationEventHandler<T> | undefined;
    onAnimationEnd?: import("react").AnimationEventHandler<T> | undefined;
    onAnimationEndCapture?: import("react").AnimationEventHandler<T> | undefined;
    onAnimationIteration?: import("react").AnimationEventHandler<T> | undefined;
    onAnimationIterationCapture?: import("react").AnimationEventHandler<T> | undefined;
    onTransitionEnd?: import("react").TransitionEventHandler<T> | undefined;
    onTransitionEndCapture?: import("react").TransitionEventHandler<T> | undefined;
    key?: import("react").Key | null | undefined;
};
export default useItem;
