import { useState, } from 'react';
import useRootClose from './useRootClose';
import { isFunction } from '../utils';
function useToken({ onBlur, onClick, onFocus, onRemove, option, ...props }) {
    const [active, setActive] = useState(false);
    const handleBlur = (e) => {
        setActive(false);
        onBlur && onBlur(e);
    };
    const handleClick = (e) => {
        setActive(true);
        onClick && onClick(e);
    };
    const handleFocus = (e) => {
        setActive(true);
        onFocus && onFocus(e);
    };
    const handleRemove = () => {
        onRemove && onRemove(option);
    };
    const handleKeyDown = (e) => {
        if (e.key === 'Backspace' && active) {
            e.preventDefault();
            handleRemove();
        }
    };
    const rootElementRef = useRootClose(handleBlur, {
        ...props,
        disabled: !active,
    });
    return {
        active,
        onBlur: handleBlur,
        onClick: handleClick,
        onFocus: handleFocus,
        onKeyDown: handleKeyDown,
        onRemove: isFunction(onRemove) ? handleRemove : undefined,
        ref: rootElementRef,
    };
}
export default useToken;
